summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2016-05-02 05:10:40 +0200
committerChristian Grothoff <christian@grothoff.org>2016-05-02 05:10:40 +0200
commitb98a204562953ee70a70a293bbe669587bc4b889 (patch)
treecbec97fc6c84152c73c2fba48dc4e17efacebe21 /src/include
parent1c2be591d3e77002c4b1d5095c06e434d9ad62fe (diff)
downloadexchange-b98a204562953ee70a70a293bbe669587bc4b889.tar.gz
exchange-b98a204562953ee70a70a293bbe669587bc4b889.tar.bz2
exchange-b98a204562953ee70a70a293bbe669587bc4b889.zip
fix #4184
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_exchange_service.h4
-rw-r--r--src/include/taler_signatures.h12
2 files changed, 8 insertions, 8 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 04f94e570..794051e26 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -95,14 +95,14 @@ struct TALER_EXCHANGE_DenomPublicKey
/**
* Timestamp indicating when coins of this denomination become invalid.
*/
- struct GNUNET_TIME_Absolute deposit_valid_until;
+ struct GNUNET_TIME_Absolute expire_deposit;
/**
* When do signatures with this denomination key become invalid?
* After this point, these signatures cannot be used in (legal)
* disputes anymore, as the Exchange is then allowed to destroy its side
* of the evidence. @e expire_legal is expected to be significantly
* larger than @e expire_spend (by a year or more).
*/
struct GNUNET_TIME_Absolute expire_legal;
@@ -95,14 +95,14 @@ struct TALER_EXCHANGE_DenomPublicKey
* disputes anymore, as the Exchange is then allowed to destroy its side
* of the evidence. @e expire_legal is expected to be significantly
- * larger than @e expire_spend (by a year or more).
+ * larger than @e expire_deposit (by a year or more).
*/
struct GNUNET_TIME_Absolute expire_legal;
diff --git a/src/include/taler_signatures.h b/src/include/taler_signatures.h
index f1586aa8c..4ce57b0f8 100644
--- a/src/include/taler_signatures.h
+++ b/src/include/taler_signatures.h
@@ -659,18 +659,18 @@ struct TALER_DenominationKeyValidityPS
* exchange will refuse transactions involving this key as it will
* "drop" the table with double-spending information (shortly after)
* this time. Note that wallets should refresh coins significantly
* before this time to be on the safe side. @e expire_spend must be
* significantly larger than @e expire_withdraw (by months or even
* years).
*/
- struct GNUNET_TIME_AbsoluteNBO expire_spend;
+ struct GNUNET_TIME_AbsoluteNBO expire_deposit;
/**
* When do signatures with this denomination key become invalid?
* After this point, these signatures cannot be used in (legal)
* disputes anymore, as the Exchange is then allowed to destroy its side
* of the evidence. @e expire_legal is expected to be significantly
* larger than @e expire_spend (by a year or more).
*/
struct GNUNET_TIME_AbsoluteNBO expire_legal;
@@ -762,18 +762,18 @@ struct TALER_ExchangeKeyValidityPS
* exchange will refuse transactions involving this key as it will
* "drop" the table with double-spending information (shortly after)
* this time. Note that wallets should refresh coins significantly
* before this time to be on the safe side. @e expire_spend must be
* significantly larger than @e expire_withdraw (by months or even
* years).
*/
- struct GNUNET_TIME_AbsoluteNBO expire_spend;
+ struct GNUNET_TIME_AbsoluteNBO expire_deposit;
/**
* When do signatures with this denomination key become invalid?
* After this point, these signatures cannot be used in (legal)
* disputes anymore, as the Exchange is then allowed to destroy its side
* of the evidence. @e expire_legal is expected to be significantly
* larger than @e expire_spend (by a year or more).
*/
struct GNUNET_TIME_AbsoluteNBO expire_legal;
@@ -659,18 +659,18 @@ struct TALER_DenominationKeyValidityPS
* "drop" the table with double-spending information (shortly after)
* this time. Note that wallets should refresh coins significantly
- * before this time to be on the safe side. @e expire_spend must be
+ * before this time to be on the safe side. @e expire_deposit must be
* significantly larger than @e expire_withdraw (by months or even
* years).
@@ -659,18 +659,18 @@ struct TALER_DenominationKeyValidityPS
* disputes anymore, as the Exchange is then allowed to destroy its side
* of the evidence. @e expire_legal is expected to be significantly
- * larger than @e expire_spend (by a year or more).
+ * larger than @e expire_deposit (by a year or more).
*/
struct GNUNET_TIME_AbsoluteNBO expire_legal;
@@ -762,18 +762,18 @@ struct TALER_ExchangeKeyValidityPS
* "drop" the table with double-spending information (shortly after)
* this time. Note that wallets should refresh coins significantly
- * before this time to be on the safe side. @e expire_spend must be
+ * before this time to be on the safe side. @e expire_deposit must be
* significantly larger than @e expire_withdraw (by months or even
* years).
@@ -762,18 +762,18 @@ struct TALER_ExchangeKeyValidityPS
* disputes anymore, as the Exchange is then allowed to destroy its side
* of the evidence. @e expire_legal is expected to be significantly
- * larger than @e expire_spend (by a year or more).
+ * larger than @e expire_deposit (by a year or more).
*/
struct GNUNET_TIME_AbsoluteNBO expire_legal;